@@ -8,7 +8,7 @@ from contextlib import contextmanager
 from mock import patch
 from nose import SkipTest
 
-from kombu.utils.encoding import safe_str, str_t
+from kombu.utils.encoding import bytes_t, safe_str, default_encoding
 
 from kombu.tests.utils import TestCase
 
@@ -26,16 +26,16 @@ def clean_encoding():
 
 class test_default_encoding(TestCase):
 
-    @patch('sys.getfilesystemencoding')
-    def test_default(self, getfilesystemencoding):
-        getfilesystemencoding.return_value = 'ascii'
+    @patch('sys.getdefaultencoding')
+    def test_default(self, getdefaultencoding):
+        getdefaultencoding.return_value = 'ascii'
         with clean_encoding() as encoding:
             enc = encoding.default_encoding()
             if sys.platform.startswith('java'):
                 self.assertEqual(enc, 'utf-8')
             else:
                 self.assertEqual(enc, 'ascii')
-                getfilesystemencoding.assert_called_with()
+                getdefaultencoding.assert_called_with()
 
 
 class test_encoding_utils(TestCase):
@@ -60,16 +60,36 @@ class test_encoding_utils(TestCase):
 
 class test_safe_str(TestCase):
 
-    def test_when_str(self):
+    def setUp(self):
+        self._cencoding = patch('sys.getdefaultencoding')
+        self._encoding = self._cencoding.__enter__()
+        self._encoding.return_value = 'ascii'
+
+    def tearDown(self):
+        self._cencoding.__exit__()
+
+    def test_when_bytes(self):
         self.assertEqual(safe_str('foo'), 'foo')
 
     def test_when_unicode(self):
-        self.assertIsInstance(safe_str(u'foo'), str_t)
+        self.assertIsInstance(safe_str(u'foo'), bytes_t)
+
+    def test_when_encoding_utf8(self):
+        with patch('sys.getdefaultencoding') as encoding:
+            encoding.return_value = 'utf-8'
+            self.assertEqual(default_encoding(), 'utf-8')
+            s = u'The quiæk fåx jømps øver the lazy dåg'
+            res = safe_str(s)
+            self.assertIsInstance(res, bytes_t)
+            self.assertGreater(len(res), len(s))
 
     def test_when_containing_high_chars(self):
-        s = u'The quiæk fåx jømps øver the lazy dåg'
-        res = safe_str(s)
-        self.assertIsInstance(res, str_t)
+        with patch('sys.getdefaultencoding') as encoding:
+            encoding.return_value = 'ascii'
+            s = u'The quiæk fåx jømps øver the lazy dåg'
+            res = safe_str(s)
+            self.assertIsInstance(res, bytes_t)
+            self.assertEqual(len(s), len(res))
 
     def test_when_not_string(self):
         o = object()
